@@ -38,8 +38,8 @@ module Rake
       @source_pattern = '**/*.java'
       @classpath      = nil
       @debug          = false
-      @source_version = '1.7'
-      @target_version = '1.7'
+      @source_version = '8'
+      @target_version = '8'
       @release        = nil
       @encoding       = nil
       @java_compiling = nil
@@ -108,8 +108,16 @@ execute the Rake compilation task using the JRuby interpreter.
         EOF
         warn_once(not_jruby_compile_msg) unless defined?(JRUBY_VERSION)
 
+        java_home = ENV["JAVA_HOME"]
+        if java_home
+          exeext = RbConfig::CONFIG["EXEEXT"]
+          javac_path = File.join(java_home, "bin", "javac#{exeext}")
+          javac_path = nil unless File.exist?(javac_path)
+        end
+        javac_path ||= "javac"
+
         javac_command_line = [
-          "javac",
+          javac_path,
           *java_target_args,
           java_lint_arg,
           "-d", tmp_path,
@@ -212,7 +220,7 @@ execute the Rake compilation task using the JRuby interpreter.
     end
 
     def java_target_args
-      if @release
+      if @release && release_flag_supported?
         ["--release=#{@release}"]
       else
         ["-target", @target_version, "-source", @source_version]
@@ -303,5 +311,11 @@ execute the Rake compilation task using the JRuby interpreter.
 
       "-Xlint:#{@lint_option}"
     end
+
+    def release_flag_supported?
+      return true unless RUBY_PLATFORM =~ /java/
+
+      Gem::Version.new(Java::java.lang.System.getProperty('java.version')) >= Gem::Version.new("9")
+    end
   end
 end
